#define F_CPU 16000000
#include <avr/io.h>
#include <util/delay.h>
#include "sin.h"

#define EL 82.4
#define A 110
#define D 146.8
#define G 196
#define B 246.9
#define EH 329.6


void PLAYNOTE(float duration, float frequency)
{
	// Physics variables
	long int i,cycles;
	float half_period;	
	float wavelength;
	 
	wavelength=(1/frequency)*1000;	
	cycles=duration/wavelength;	    
	half_period = wavelength/2;		

	DDRC |= (1 << PC7);

	for (i=0;i<cycles;i++) 			
	{
		_delay_ms(half_period);							
		PORTC |= (1 << PC7);					
		_delay_ms(half_period);						
		PORTC &= ~(1 << PC7);				
	}

	return;		
}


void adc_init() 

{

	ADCSRA |= ((1<<ADPS2)|(1<<ADPS1)|(1<<ADPS0));    //16Mhz/128 = 125Khz the ADC reference clock
	ADMUX |= (1<<REFS0);                //Voltage reference from Avcc (5v)
	ADCSRA |= (1<<ADEN);                //Turn on ADC
	ADCSRA |= (1<<ADSC);                 
}

unsigned int  adc_read() {
 
    ADCSRA |= _BV(ADSC); //start first conversion
	loop_until_bit_is_set(ADCSRA,ADIF); 
	return ADC;
}



int main()
{

	unsigned int  v = 0;
	DDRD = 0xFF;

	adc_init();
	while(1) {

		ADMUX |= (1<<MUX2)|(1<<MUX1)|(1<<MUX0); // ADC7
        v = adc_read();
		if (v > 200)
			PLAYNOTE(500,EL);
		
		ADMUX |= (1<<MUX2)|(1<<MUX1); // ADC6
		ADMUX &= ~(1<<MUX0);
        v = adc_read();
		if (v > 200)
			PLAYNOTE(500,A);
			
		ADMUX |= (1<<MUX2)|(1<<MUX0); // ADC5
		ADMUX &= ~(1<<MUX1);
        v = adc_read();
		if (v > 200)
			PLAYNOTE(500,D);
			
		ADMUX |= (1<<MUX2); // ADC4
		ADMUX &= ~((1<<MUX1)|(1<<MUX0));
        v = adc_read();
		if (v > 400) // 400 fiindca laserul nu da exact pe photorezistenta.
			PLAYNOTE(500,G);
			
		ADMUX |= (1<<MUX1)|(1<<MUX0); // ADC3
		ADMUX &= ~(1<<MUX2);
        v = adc_read();
		if (v > 200)
			PLAYNOTE(500,B);
			
		ADMUX |= (1<<MUX1); // ADC2
		ADMUX &= ~((1<<MUX2)|(1<<MUX0));
        v = adc_read();
		if (v > 200)
			PLAYNOTE(500,EH);
	


	}
	
	return 0;
	
}
